﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Drawing;
using nQuant;
using System.Drawing.Imaging;

namespace CnCNetPreviewGen
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 1 || !File.Exists(args[0]))
                return;

            var file = File.ReadAllBytes(args[0]);
            var bitmap = new Bitmap(new MemoryStream(file));

            if (bitmap.Width > 256 || bitmap.Height > 256)
            {
                Console.WriteLine("Error: Image too big. Max Width and Height are 256");
                Console.ReadLine();
                return;
            }

            //always use 256x256 sized bitmap and center in case the original one is smaller
            var centerBitmap = new Bitmap(256, 256);
            using (var graphics = Graphics.FromImage(centerBitmap))
            {
                int x = 256 / 2 - bitmap.Width / 2;
                int y = 256 / 2 - bitmap.Height / 2;

                graphics.InterpolationMode = System.Drawing.Drawing2D.InterpolationMode.NearestNeighbor;
                graphics.DrawImage(bitmap, x, y, bitmap.Width, bitmap.Height);
            }

            var quantizer = new WuQuantizer();
            MemoryStream ms = new MemoryStream();

            using (var quantized = quantizer.QuantizeImage(centerBitmap))
            {
                quantized.Save(ms, ImageFormat.Png);
            }

            string b64 = Convert.ToBase64String(ms.ToArray());

            using (var sw = new StreamWriter(Path.ChangeExtension(args[0], "preview.ini")))
            {
                sw.WriteLine("[CnCNetPreview]");

                int i = 0;
                foreach(var s in Split(b64, 70))
                    sw.WriteLine(i++.ToString() + "=" + s);
            }
        }

        static IEnumerable<string> Split(string str, int maxChunkSize)
        {
            for (int i = 0; i < str.Length; i += maxChunkSize)
                yield return str.Substring(i, Math.Min(maxChunkSize, str.Length - i));
        }
    }
}
